rai\_toolbox.datasets.CIFAR100C
===============================

.. currentmodule:: rai_toolbox.datasets

.. autoclass:: CIFAR100C

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CIFAR100C.__init__

   
   